SWDEV-269246 - Added missing exports for hipArrayDestroy

Change-Id: I730814720bb618e895efbe2f412e437110bed8bc


[ROCm/clr commit: 9f142f988d]
Este commit está contenido en:
Arya.Rafii
2021-03-01 11:05:31 -05:00
cometido por Arya Rafii
padre 2b715e4826
commit cd4aec747f
Se han modificado 3 ficheros con 4 adiciones y 0 borrados
@@ -2300,6 +2300,8 @@ hipError_t hipMallocArray(hipArray** array, const hipChannelFormatDesc* desc, si
size_t height __dparm(0), unsigned int flags __dparm(hipArrayDefault));
hipError_t hipArrayCreate(hipArray** pHandle, const HIP_ARRAY_DESCRIPTOR* pAllocateArray);
hipError_t hipArrayDestroy(hipArray* array);
hipError_t hipArray3DCreate(hipArray** array, const HIP_ARRAY3D_DESCRIPTOR* pAllocateArray);
hipError_t hipMalloc3D(hipPitchedPtr* pitchedDevPtr, hipExtent extent);
+1
Ver fichero
@@ -84,6 +84,7 @@ hipMalloc3DArray
hipMallocManaged
hipArrayCreate
hipArray3DCreate
hipArrayDestroy
hipMallocArray
hipMemAdvise
hipMemAllocPitch
+1
Ver fichero
@@ -85,6 +85,7 @@ global:
hipMalloc3DArray;
hipMallocManaged;
hipArrayCreate;
hipArrayDestroy;
hipArray3DCreate;
hipMallocArray;
hipMallocPitch;